@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use strict;
 
 package Mail::Box::Locker::Multi;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 use base 'Mail::Box::Locker';
 
@@ -20,7 +20,7 @@ sub init($)
 
     my @use
      = exists $args->{use} ? @{delete $args->{use}}
-     : $^O =~ m/mswin/i    ? qw/    POSIX Flock/
+     : $^O eq 'MSWin32'    ? qw/Flock/
      :                       qw/NFS POSIX Flock/;
 
     my (@lockers, @used);
