@@ -1,12 +1,12 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use strict;
 package Mail::Box::Net;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 
 use base 'Mail::Box';
@@ -32,15 +32,31 @@ sub init($)
 
     $args->{lock_type}  ||= 'NONE';
     $args->{body_type}  ||= 'Mail::Message::Body::Lines';
-    $args->{folder}     ||= '/';
     $args->{trusted}    ||= 0;
 
+    my ($scheme, $s, $port, $u, $pwd, $f);
+    if(my $d = $args->{folderdir})
+    {   # cannot use URI, because some scheme's are fake
+        ($scheme, $u, $pwd, $s, $port, $f) = $a =~
+          m! ^ (\w+) \://                # scheme
+               (?: ( [^:\@/]+ )          # username
+                   (?:  \: ( [^\@/]+ ))? # password
+                   \@ )?
+               ( [a-zA-Z0-9.-]+ )?       # hostname
+               (?: \: ([0-9]+)  )?       # port
+               ( / .* )?                 # path
+          !x;
+        $args->{folderdir} =~ s!/$!!;
+    }
+
+    $args->{folder}     ||= $f || '/';
+
     $self->SUPER::init($args);
 
-    $self->{MBN_username} = $args->{username};
-    $self->{MBN_password} = $args->{password};
-    $self->{MBN_hostname} = $args->{server_name};
-    $self->{MBN_port}     = $args->{server_port};
+    $self->{MBN_hostname} = $args->{server_name}  || $s;
+    $self->{MBN_port}     = $args->{server_port}  || $port;
+    $self->{MBN_username} = $args->{username}     || $u;
+    $self->{MBN_password} = $args->{password}     || $pwd;
 
     $self->log(WARNING => "The term 'hostname' is confusing wrt folder. You probably need 'server_name'")
          if exists $args->{hostname};
@@ -48,22 +64,10 @@ sub init($)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub create(@) {shift->notImplemented}
-
-#-------------------------------------------
-
-
-sub folderdir(;$) { undef }
-
-#-------------------------------------------
-
 sub organization() { 'REMOTE' }
 
-#-------------------------------------------
-
 sub url()
 {   my $self = shift;
 
@@ -88,6 +92,4 @@ sub url()
     $self->type . '://' . $perm . $loc;
 }
 
-#-------------------------------------------
-
 1;
