@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Box::Parser::Perl;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 use base 'Mail::Box::Parser';
 
@@ -184,6 +184,9 @@ sub _read_stripped_lines(;$$)
         }
         unless($self->{MBPP_trusted})
         {   s/\015$// for @$lines;
+            # input is read as binary stream (i.e. preserving CRLF on Windows).
+            # Code is based on this assumption. Removal of CR if not trusted
+            # conflicts with this assumption. [Markus Spann]
         }
     }
 #warn "($bodyend, $msgend, ".@$lines, ")\n";
@@ -270,7 +273,7 @@ sub openFile($)
     $self->{MBPP_file}       = $fh;
 
     $fh->binmode(':raw')
-       if ref($fh) eq 'GLOB' || $fh->can('BINMODE');
+        if $fh->can('binmode') || $fh->can('BINMODE');
 
     $self->{MBPP_separators} = [];
 
