@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Body::File;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 use base 'Mail::Message::Body';
 
@@ -25,14 +25,14 @@ sub _data_from_filename(@)
     local $_;
     local (*IN, *OUT);
 
-    unless(open IN, '<', $filename)
+    unless(open IN, '<:raw', $filename)
     {   $self->log(ERROR =>
             "Unable to read file $filename for message body file: $!");
         return;
     }
 
     my $file   = $self->tempFilename;
-    unless(open OUT, '>', $file)
+    unless(open OUT, '>:raw', $file)
     {   $self->log(ERROR => "Cannot write to temporary body file $file: $!");
         return;
     }
@@ -54,7 +54,7 @@ sub _data_from_filehandle(@)
 
     local *OUT;
 
-    unless(open OUT, '>', $file)
+    unless(open OUT, '>:raw', $file)
     {   $self->log(ERROR => "Cannot write to temporary body file $file: $!");
         return;
     }
@@ -77,7 +77,7 @@ sub _data_from_glob(@)
     local $_;
     local *OUT;
 
-    unless(open OUT, '>', $file)
+    unless(open OUT, '>:raw', $file)
     {   $self->log(ERROR => "Cannot write to temporary body file $file: $!");
         return;
     }
@@ -98,7 +98,7 @@ sub _data_from_lines(@)
 
     local *OUT;
 
-    unless(open OUT, '>', $file)
+    unless(open OUT, '>:raw', $file)
     {   $self->log(ERROR => "Cannot write to $file: $!");
         return;
     }
@@ -134,7 +134,7 @@ sub nrLines()
     local $_;
     local *IN;
 
-    open IN, '<', $file
+    open IN, '<:raw', $file
         or die "Cannot read from $file: $!\n";
 
     $nrlines++ while <IN>;
@@ -166,7 +166,7 @@ sub string()
 
     local *IN;
 
-    open IN, '<', $file
+    open IN, '<:raw', $file
         or die "Cannot read from $file: $!\n";
 
     my $return = join '', <IN>;
@@ -181,7 +181,7 @@ sub lines()
     my $file = $self->tempFilename;
 
     local *IN;
-    open IN, '<', $file
+    open IN, '<:raw', $file
         or die "Cannot read from $file: $!\n";
 
     my @r = <IN>;
@@ -192,7 +192,7 @@ sub lines()
 }
 
 sub file()
-{   open my $tmp, '<', shift->tempFilename;
+{   open my $tmp, '<:raw', shift->tempFilename;
     $tmp;
 }
 
@@ -204,7 +204,7 @@ sub print(;$)
     local $_;
     local *IN;
 
-    open IN, '<', $file
+    open IN, '<:raw', $file
         or croak "Cannot read from $file: $!\n";
 
     if(ref $fh eq 'GLOB') {print $fh $_ while <IN>}
@@ -220,7 +220,7 @@ sub read($$;$@)
 
     local *OUT;
 
-    open OUT, '>', $file
+    open OUT, '>:raw', $file
         or die "Cannot write to $file: $!.\n";
 
     (my $begin, my $end, $self->{MMBF_nrlines}) = $parser->bodyAsFile(\*OUT,@_);
