@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Body::Multipart;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 use base 'Mail::Message::Body';
 
@@ -231,14 +231,18 @@ sub encoded()
 sub read($$$$)
 {   my ($self, $parser, $head, $bodytype) = @_;
 
-    my $boundary = $self->boundary;
+    my $boundary   = $self->boundary;
 
     $parser->pushSeparator("--$boundary");
-    my @msgopts  = ($self->logSettings);
+    my @msgopts    = ($self->logSettings);
 
+    my $te;
+    $te = lc $1
+        if +($head->get('Content-Transfer-Encoding') || '') =~ m/(\w+)/;
+    
     my @sloppyopts = 
       ( mime_type         => 'text/plain'
-      , transfer_encoding => ($head->get('Content-Transfer-Encoding') || undef)
+      , transfer_encoding => $te
       );
 
     # Get preamble.
