@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Field::AddrGroup;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 use base 'User::Identity::Collection::Emails';
 
@@ -20,7 +20,7 @@ use overload '""' => 'string';
 sub string()
 {   my $self = shift;
     my $name = $self->name;
-    my @addr = sort map {$_->string} $self->addresses;
+    my @addr = sort map $_->string, $self->addresses;
 
     local $" = ', ';
 
