@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Head;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 use base 'Mail::Reporter';
 
@@ -98,7 +98,7 @@ sub message(;$)
 }
 
 
-sub orderedFields() { grep {defined $_} @{shift->{MMH_order}} }
+sub orderedFields() { grep defined $_, @{shift->{MMH_order}} }
 
 
 sub knownNames() { keys %{shift->{MMH_fields}} }
