@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Head::Complete;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 use base 'Mail::Message::Head';
 
@@ -61,15 +61,13 @@ sub build(@)
 sub isDelayed() {0}
 
 
-sub nrLines() { sum 1, map { $_->nrLines } shift->orderedFields }
-
-
-sub size() { sum 1, map {$_->size} shift->orderedFields }
+sub nrLines() { sum 1, map $_->nrLines, shift->orderedFields }
+sub size() { sum 1, map $_->size, shift->orderedFields }
 
 
 sub wrap($)
 {   my ($self, $length) = @_;
-    $_->setWrapLength($length) foreach $self->orderedFields;
+    $_->setWrapLength($length) for $self->orderedFields;
 }
 
 #------------------------------------------
@@ -189,7 +187,7 @@ sub reset($@)
     # Cloning required, otherwise double registrations will not be
     # removed from the ordered list: that's controled by 'weaken'
 
-    my @fields = map {$_->clone} @_;
+    my @fields = map $_->clone, @_;
 
     if(@_==1) { $known->{$name} = $fields[0] }
     else      { $known->{$name} = [@fields]  }
