@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use strict;
 
 package Mail::Message::Head::Subset;
 use vars '$VERSION';
-$VERSION = '2.106';
+$VERSION = '2.118';
 
 use base 'Mail::Message::Head';
 
@@ -21,17 +21,11 @@ use Date::Parse;
 
 sub count($)
 {   my ($self, $name) = @_;
-
-    my @values = $self->get($name);
-
-    return $self->load->count($name)
-       unless @values;
-
+    my @values = $self->get($name)
+        or return $self->load->count($name);
     scalar @values;
 }
 
-#-------------------------------------------
-
 
 sub get($;$)
 {   my $self = shift;
@@ -51,7 +45,6 @@ sub get($;$)
 
 #-------------------------------------------
 
-
 sub guessBodySize()
 {   my $self = shift;
 
@@ -89,9 +82,6 @@ sub guessTimestamp()
 
 #-------------------------------------------
 
-
 sub load() { $_[0] = $_[0]->message->loadHead }
 
-#------------------------------------------
-
 1;
